Binary Optimization
===================

.. autofunction:: qcware.optimization.solve_binary


Optimal QAOA Angles
========================
.. autofunction:: qcware.optimization.find_optimal_qaoa_angles
